<?php
/**
 * Field: Border2
 */
class MTS_Options_border2 extends MTS_Options {

	public function __construct( $field = [], $value = '', $parent = [] ) {

		parent::__construct( $parent->sections, $parent->args, $parent->extra_tabs );
		$this->field = wp_parse_args( $field, array(
			'top'    => true,
			'right'  => true,
			'bottom' => true,
			'left'   => true,
			'color'  => true,
			'style'  => true,
		));
		$this->value = $value;
	}

	public function render() {

		$defaults = array(
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
			'color'  => '',
			'style'  => 'none',
		);

		$options = array(
			'none'   => 'None',
			'solid'  => 'Solid',
			'dashed' => 'Dashed',
			'dotted' => 'Dotted',
			'double' => 'Double',
			'groove' => 'Groove',
			'ridge'  => 'Ridge',
			'inset'  => 'Inset',
			'outset' => 'Outset',
		);

		$name = $this->args['opt_name'] . '[' . $this->field['id'] . ']';

		$defaults    = isset( $this->field['std'] ) ? wp_parse_args( $this->field['std'], $defaults ) : $defaults;
		$this->value = wp_parse_args( $this->value, $defaults );

		$sides = array(
			'top'    => array(
				'title' => esc_html__( 'Top', 'chronicle' ),
				'icon'  => 'dashicons dashicons-arrow-up-alt',
			),
			'right'  => array(
				'title' => esc_html__( 'Right', 'chronicle' ),
				'icon'  => 'dashicons dashicons-arrow-right-alt',
			),
			'bottom' => array(
				'title' => esc_html__( 'Bottom', 'chronicle' ),
				'icon'  => 'dashicons dashicons-arrow-down-alt',
			),
			'left'   => array(
				'title' => esc_html__( 'Left', 'chronicle' ),
				'icon'  => 'dashicons dashicons-arrow-left-alt',
			),
		);

		echo '<div class="nhpoptions-border2" id="' . $this->field['id'] . '">';

		echo '<div class="border2-wrap">';
		foreach ( $sides as $id => $val ) {

			if ( ! $this->field[ $id ] ) {
				continue;
			}

			printf(
				'<div class="border2-item"><span class="mg-side">%1$s</span><span class="%2$s"></span><input type="text" id="%3$s-%4$s" name="%5$s[%3$s][%4$s]" value="%6$s"></div>',
				$val['title'],
				$val['icon'],
				$this->field['id'],
				$id,
				$this->args['opt_name'],
				esc_attr( $this->value[ $id ] )
			);
		}

		echo '</div>';
		?>
		<input type="text" id="<?php echo $this->field['id']; ?>" name="<?php echo $name; ?>[color]" value="<?php echo $this->value['color']; ?>" class="popup-colorpicker" data-default-color=""<?php echo isset( $this->field['args']['opacity'] ) ? 'data-alpha="true"' : ''; ?>/>

		<select name="<?php echo $name; ?>[style]">
			<?php
			foreach ( $options as $k => $v ) {
				echo '<option value="' . $k . '"' . selected( $this->value['style'], $k, false ) . '>' . $v . '</option>';
			}
			?>
		</select>
		<?php

		echo '</div>';

		$this->print_description();
	}

	public function enqueue() {

		wp_enqueue_style( 'wp-color-picker' );

		if ( ! wp_script_is( 'wp-color-picker-alpha-js' ) ) {
			wp_enqueue_script(
				'wp-color-picker-alpha-js',
				$this->url . 'fields/color/wp-color-picker-alpha.min.js',
				array( 'wp-color-picker' ),
				chronicle()->get_version(),
				true
			);
		}
	}
}
