<?php
/**
 * Set chronicle layout according to options
 *
 * @package Chronicle
 */

defined( 'WPINC' ) || exit;

/**
 * Layout manager.
 */
class Chronicle_Layout extends Chronicle_Base {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->add_action( 'chronicle_before_wrapper', 'add_header' );
		$this->add_action( 'chronicle_single_post_full_header', 'single_post_full_header' );
		$this->add_action( 'chronicle_single_post_header_thumb', 'single_post_header_thumb' );
		$this->add_action( 'chronicle_breadcrumb_lists', 'breadcrumb_lists' );
		$this->add_action( 'chronicle_before_footer', 'full_related_posts' );
	}

	/**
	 * Add header
	 */
	public function add_header() {
		$hash   = array(
			'header-default' => 'default',
			'header-layout2' => 'layout2',
		);
		$layout = chronicle_get_settings( 'header_styles' );
		get_template_part( 'template-parts/header/header', isset( $hash[ $layout ] ) ? $hash[ $layout ] : $layout );
	}

	/**
	 * Single post header thumbnail
	 */
	public function single_post_header_thumb() {
		$img_size         = chronicle_get_settings( 'featured_image_size' );
		$header_animation = chronicle_get_post_header_effect();
		if ( 'default' === $img_size ) :
			if ( ! has_post_thumbnail() ) {
				return;
			}
			chronicle_single_featured_image_effect();
			if ( ! $header_animation && chronicle_get_settings( 'show_single_featured' ) ) {
				$attr = [
					'class'   => 'single-featured-image',
					'title'   => esc_attr( get_the_title() ),
					'alt'     => esc_attr( get_the_title() ),
					'loading' => 'lazy',
				];
				the_post_thumbnail( 'chronicle-layout-2', $attr );
			}
			?>
			<header>
				<?php chronicle_the_post_meta( 'single' ); ?>
				<h1 class="single-title"><?php the_title(); ?></h1>
			</header>
			<?php
		endif;
	}

	/**
	 * Single post header if fullwidth layout
	 */
	public function single_post_full_header() {
		$img_size         = chronicle_get_settings( 'featured_image_size' );
		$alignment        = chronicle_get_settings( 'featured_text_alignment' );
		$header_animation = chronicle_get_post_header_effect();
		if ( 'full' === $img_size ) :
			if ( have_posts() ) :
				while ( have_posts() ) :
					the_post();
					global $post;
					echo '<div class="single-full-header single-post-' . $alignment . ' clearfix">';
					echo '<div class="container">';
					chronicle_single_featured_image_effect();
					if ( ! $header_animation && chronicle_get_settings( 'show_single_featured' ) ) {
						$attr = [
							'class'   => 'single-featured-image',
							'title'   => esc_attr( get_the_title() ),
							'alt'     => esc_attr( get_the_title() ),
							'loading' => 'lazy',
						];
						the_post_thumbnail( 'chronicle-full-header', $attr );
					}
					?>
					<header>
						<?php chronicle_the_post_meta( 'single' ); ?>
						<h1 class="single-title"><?php the_title(); ?></h1>
					</header>
					<?php
					if ( chronicle_get_settings( 'show_prev_next' ) ) {
						?>
						<div class="prev-next">
							<?php
							previous_post_link( '<div class="prev">%link</div>', '<i class="fa fa-angle-left"></i>', true );
							next_post_link( '<div class="next">%link</div>', '<i class="fa fa-angle-right"></i>', true );
							?>
						</div>
						<?php
					}
					echo '</div>';
					echo '</div>';
				endwhile;
			endif; /* end loop */
		endif;
	}

	/**
	 * Breadcrumb
	 */
	public function breadcrumb_lists() {
		chronicle_breadcrumbs();
	}

	/**
	 * Single post related posts
	 */
	public function full_related_posts( $position = 'full' ) {
		if ( 'full' === chronicle_get_settings( 'related_posts_position' ) ) {
			chronicle_related_posts();
		}
	}

}

// Init.
new Chronicle_Layout;
