<?php
/**
 * Archive Pages
 *
 * @package Chronicle
 */

$menus['blog-archive'] = array(
	'icon'  => 'fa-archive',
	'title' => esc_html__( 'Archives', 'chronicle' ),
	'desc'  => esc_html__( 'From here, you can control the elements of the archive pages.', 'chronicle' ),
);

// Dependency check that excerpt is enable.
$archive_excerpt_dependency = array(
	'relation' => 'and',
	array(
		'field'      => 'archive_post_excerpt',
		'value'      => '1',
		'comparison' => '==',
	),
);

$archive_post_hover_dependency = array(
	'relation' => 'and',
	array(
		'field'      => 'archive_post_hover',
		'value'      => '1',
		'comparison' => '==',
	),
);

$sections['blog-archive'] = array(
	// Post Alignment
	array(
		'id'    => 'archive_post_content_alignment',
		'type'  => 'heading',
		'title' => esc_html__( 'Post Alignment & Hover Settings', 'chronicle' ),
	),
	array(
		'id'       => 'archive_post_alignment',
		'type'     => 'button_set',
		'title'    => esc_html__( 'Post Alignment', 'chronicle' ),
		'sub_desc' => esc_html__( 'Choose the post alignment', 'chronicle' ),
		'options'  => array(
			'left'   => esc_html__( 'Left', 'chronicle' ),
			'center' => esc_html__( 'Center', 'chronicle' ),
			'right'  => esc_html__( 'Right', 'chronicle' ),
		),
		'std'      => 'center',
	),
	array(
		'id'       => 'archive_post_hover',
		'type'     => 'switch',
		'title'    => esc_html__( 'Post Hover Effect', 'chronicle' ),
		'sub_desc' => esc_html__( 'Use this button to show or hide hover effect.', 'chronicle' ),
		'std'      => '1',
	),
	array(
		'id'         => 'archive_view_more_title',
		'type'       => 'text',
		'title'      => esc_html__( 'Read More Title', 'chronicle' ),
		'sub_desc'   => esc_html__( 'Enter the title text to show Read More button.', 'chronicle' ),
		'std'        => 'Read More',
		'dependency' => $archive_post_hover_dependency,
	),
	array(
		'id'         => 'archive_view_more_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Read More Typography', 'chronicle' ),
		'std'        => array(
			'preview-text'   => 'Read More Font',
			'preview-color'  => 'light',
			'font-family'    => 'Public Sans',
			'font-weight'    => '700',
			'font-size'      => '15px',
			'color'          => '#1a282f',
			'additional-css' => 'text-align: center;',
			'css-selectors'  => '.archive .latestPost .view-more, .search .latestPost .view-more, .archive [class^="more-page"] .latestPost .view-more, .search [class^="more-page"] .latestPost .view-more',
		),
		'dependency' => $archive_post_hover_dependency,
	),
	array(
		'id'         => 'archive_view_more_bg',
		'type'       => 'color',
		'title'      => esc_html__( 'Read More Background', 'chronicle' ),
		'std'        => '#ffffff',
		'dependency' => $archive_post_hover_dependency,
	),
	array(
		'id'         => 'archive_post_overlay',
		'type'       => 'color',
		'title'      => esc_html__( 'Post Overlay Background', 'chronicle' ),
		'args'       => array( 'opacity' => true ),
		'std'        => 'rgba(46,95,214,0.51)',
		'dependency' => $archive_post_hover_dependency,
	),
	array(
		'id'    => 'archive_post_title_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Archive Post Font', 'chronicle' ),
	),
	array(
		'id'    => 'archive_post_title_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Post Title Font', 'chronicle' ),
		'std'   => array(
			'preview-text'  => 'Post Title Font',
			'preview-color' => 'light',
			'font-family'   => 'Public Sans',
			'font-weight'   => '700',
			'font-size'     => '18px',
			'line-height'   => chronicle_line_height( 18, 26 ),
			'margin-bottom' => '5px',
			'color'         => '#1a282f',
			'css-selectors' => '.latestPost .title a, .archive .latestPost .title a, .search .latestPost .title a, .archive [class^="more-page"] .latestPost .title a, .search [class^="more-page"] .latestPost .title a',
		),
	),
	array(
		'id'       => 'archive_post_excerpt',
		'type'     => 'switch',
		'title'    => esc_html__( 'Show Post Excerpts', 'chronicle' ),
		'sub_desc' => esc_html__( 'Use this button to show or hide small post excerpt.', 'chronicle' ),
		'std'      => '0',
	),
	array(
		'id'         => 'archive_excerpt',
		'type'       => 'text',
		'class'      => 'small-text',
		'title'      => esc_html__( 'Excerpt Length', 'magnus' ),
		'sub_desc'   => esc_html__( 'Max lenght is 55 Words.', 'magnus' ),
		'args'       => array( 'type' => 'number' ),
		'std'        => '15',
		'dependency' => $archive_excerpt_dependency,
	),
	array(
		'id'         => 'archive_post_excerpt_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Post Excerpt Font', 'chronicle' ),
		'std'        => array(
			'preview-text'  => 'Post Excerpt Font',
			'preview-color' => 'light',
			'font-family'   => 'Public Sans',
			'font-weight'   => '400',
			'font-size'     => '15px',
			'line-height'   => chronicle_line_height( 15, 22 ),
			'color'         => '#1a282f',
			'css-selectors' => '.archive .latestPost .front-view-content, .search .latestPost .front-view-content, .archive [class^="more-page"] .latestPost .front-view-content, .search [class^="more-page"] .latestPost .front-view-content',
		),
		'dependency' => $archive_excerpt_dependency,
	),
	array(
		'id'       => 'mts_archive_headline_meta_info',
		'type'     => 'layout2',
		// translators: title.
		'title'    => esc_html__( 'Archive Posts Meta Info', 'chronicle' ),
		// translators: description.
		'sub_desc' => esc_html__( 'Organize how you want the post meta info to appear on Archive Posts', 'chronicle' ),
		'options'  => array(
			'enabled'  => array(
				'category' => array(
					'label'     => esc_html__( 'Categories', 'chronicle' ),
					'subfields' => array(
						array(
							'id'    => 'mts_archive_meta_info_category_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'chronicle' ),
						),
					),
				),
				'date'     => array(
					'label'     => esc_html__( 'Date', 'chronicle' ),
					'subfields' => array(
						array(
							'id'    => 'mts_archive_meta_info_date_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'chronicle' ),
						),
					),
				),
			),
			'disabled' => array(
				'author'  => array(
					'label'     => esc_html__( 'Author Name', 'chronicle' ),
					'subfields' => array(
						array(
							'id'    => 'mts_archive_meta_info_author_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'chronicle' ),
						),
					),
				),
				'comment' => array(
					'label'     => esc_html__( 'Comment Count', 'chronicle' ),
					'subfields' => array(
						array(
							'id'    => 'mts_archive_meta_info_comment_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'chronicle' ),
						),
					),
				),
			),
		),
		'std'      => array(
			'enabled'  => array(
				'category' => array(
					'label'     => esc_html__( 'Categories', 'chronicle' ),
					'subfields' => array(
						array(
							'id'    => 'mts_archive_meta_info_category_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'chronicle' ),
						),
					),
				),
				'date'     => array(
					'label'     => esc_html__( 'Date', 'chronicle' ),
					'subfields' => array(
						array(
							'id'    => 'mts_archive_meta_info_date_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'chronicle' ),
						),
					),
				),
			),
			'disabled' => array(
				'author'  => array(
					'label'     => esc_html__( 'Author Name', 'chronicle' ),
					'subfields' => array(
						array(
							'id'    => 'mts_archive_meta_info_author_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'chronicle' ),
						),
					),
				),
				'comment' => array(
					'label'     => esc_html__( 'Comment Count', 'chronicle' ),
					'subfields' => array(
						array(
							'id'    => 'mts_archive_meta_info_comment_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'chronicle' ),
						),
					),
				),
			),
		),
	),
	array(
		'id'    => 'archive_meta_info_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Post Meta Info Typography', 'chronicle' ),
		'std'   => array(
			'preview-text'   => 'Post Meta Info Font',
			'preview-color'  => 'light',
			'font-family'    => 'Public Sans',
			'font-weight'    => '400',
			'font-size'      => '11px',
			'color'          => '#1a282f',
			'line-height'    => '1.2',
			'letter-spacing' => chronicle_letter_spacing( 11, 182 ),
			'margin-bottom'  => '-5px',
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '.archive .latestPost .post-info, .search .latestPost .post-info',
		),
	),
);
