<?php
/**
 * HomePage Posts
 *
 * @package Chronicle
 */

$features = chronicle_get_settings( 'featured_categories' );
if ( empty( $features ) ) {
	return;
}
foreach ( $features as $feature ) :
	$title        = isset( $feature['mts_featured_title'] ) ? $feature['mts_featured_title'] : 'No Title';
	$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : '';
	if ( 'layout-default' === $posts_layout ) {
		$posts_layout = 'default';
	}
	$unique_id = isset( $feature['unique_id'] ) ? $feature['unique_id'] : '';

	$menus['blog']['child'][ 'blog-' . $unique_id ] = array(
		'title' => $title,
		// translators: description.
		'desc'  => sprintf( wp_kses_post( __( 'From here, you can control the elements of %s', 'chronicle' ) ), $title ),
	);

	// Dependency check that Title is enable.
	$post_title_dependency = array(
		'field'      => 'featured_category_title_' . $unique_id,
		'value'      => '1',
		'comparison' => '==',
	);

	// Dependency check that excerpt is enable.
	$post_excerpt_dependency = array(
		'relation' => 'and',
		array(
			'field'      => 'post_excerpt_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		),
	);

	$post_hover_dependency = array(
		'relation' => 'and',
		array(
			'field'      => 'post_hover_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		),
	);

	$sections[ 'blog-' . $unique_id ] = array(

		/**
		 * Layout Default Settings
		 *
		 * @package Chronicle
		 */

		// Section Title.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'chronicle' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'chronicle' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'chronicle' ),
			'std'      => '0',
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'chronicle' ),
			'std'        => array(
				'preview-text'   => 'Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '700',
				'font-size'      => chronicle_px2rem( '24px' ),
				'line-height'    => '1.2',
				'color'          => '#1a282f',
				'letter-spacing' => chronicle_letter_spacing( 24, 16 ),
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => array(
				'relation' => 'and',
				$post_title_dependency,
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'chronicle' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'chronicle' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => chronicle_px2rem( '30px' ),
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				$post_title_dependency,
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'chronicle' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'chronicle' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				$post_title_dependency,
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'chronicle' ),
			'sub_desc'   => esc_html__( 'Select border', 'chronicle' ),
			'dependency' => array(
				'relation' => 'and',
				$post_title_dependency,
			),
		) : null,
		// Post Alignment
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_content_alignment_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Alignment & Hover Settings', 'chronicle' ),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_alignment_' . $unique_id,
			'type'     => 'button_set',
			'title'    => esc_html__( 'Post Alignment', 'chronicle' ),
			'sub_desc' => esc_html__( 'Choose the post alignment', 'chronicle' ),
			'options'  => array(
				'left'   => esc_html__( 'Left', 'chronicle' ),
				'center' => esc_html__( 'Center', 'chronicle' ),
				'right'  => esc_html__( 'Right', 'chronicle' ),
			),
			'std'      => 'center',
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_hover_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Post Hover Effect', 'chronicle' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide hover effect.', 'chronicle' ),
			'std'      => '1',
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'view_more_title_' . $unique_id,
			'type'       => 'text',
			'title'      => esc_html__( 'Read More Title', 'chronicle' ),
			'sub_desc'   => esc_html__( 'Enter the title text to show Read More button.', 'chronicle' ),
			'std'        => 'Read More',
			'dependency' => $post_hover_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'view_more_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Read More Typography', 'chronicle' ),
			'std'        => array(
				'preview-text'   => 'Read More Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '700',
				'font-size'      => '15px',
				'color'          => '#1a282f',
				'additional-css' => 'text-align: center;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .view-more',
			),
			'dependency' => $post_hover_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'view_more_bg_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Read More Background', 'chronicle' ),
			'std'        => '#ffffff',
			'dependency' => $post_hover_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'post_overlay_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Post Overlay Background', 'chronicle' ),
			'args'       => array( 'opacity' => true ),
			'std'        => 'rgba(46,95,214,0.51)',
			'dependency' => $post_hover_dependency,
		) : null,
		// Meta info.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'chronicle' ),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'chronicle' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'chronicle' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'category' => array(
						'label'     => esc_html__( 'Categories', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
				),
				'disabled' => array(
					'author'  => array(
						'label'     => __( 'Author Name', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(
					'category' => array(
						'label'     => esc_html__( 'Categories', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
				),
				'disabled' => array(
					'author'  => array(
						'label'     => __( 'Author Name', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
				),
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'chronicle' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '400',
				'font-size'      => '11px',
				'color'          => '#1a282f',
				'line-height'    => '1.2',
				'letter-spacing' => chronicle_letter_spacing( 11, 182 ),
				'margin-bottom'  => '-5px',
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info',
			),
		) : null,
		// Post Container.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'chronicle' ),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'chronicle' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'chronicle' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'chronicle' ),
			'sub_desc' => esc_html__( 'Select border', 'chronicle' ),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'chronicle' ),
			'sub_desc' => esc_html__( 'Post margin.', 'chronicle' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => chronicle_px2rem( '40px' ),
				'bottom' => '0',
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'chronicle' ),
			'sub_desc' => esc_html__( 'Post padding.', 'chronicle' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'chronicle' ),
			'std'   => array(
				'preview-text'  => 'Post Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Public Sans',
				'font-weight'   => '700',
				'font-size'     => '18px',
				'line-height'   => chronicle_line_height( 18, 26 ),
				'margin-bottom' => '5px',
				'color'         => '#1a282f',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_excerpt_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show Post Excerpts', 'chronicle' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide post excerpt.', 'chronicle' ),
			'std'      => '0',
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'post_excerpt_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Post Excerpt Font', 'chronicle' ),
			'std'        => array(
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Public Sans',
				'font-weight'   => '400',
				'font-size'     => '15px',
				'line-height'   => chronicle_line_height( 15, 22 ),
				'color'         => '#1a282f',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
			'dependency' => $post_excerpt_dependency,
		) : null,

		/**
		 * Layout 1 Settings
		 *
		 * @package Chronicle
		 */

		// Section Title.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'chronicle' ),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'chronicle' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'chronicle' ),
			'std'      => '1',
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'chronicle' ),
			'std'        => array(
				'preview-text'   => 'Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '700',
				'font-size'      => chronicle_px2rem( '24px' ),
				'line-height'    => '1.2',
				'color'          => '#1a282f',
				'letter-spacing' => chronicle_letter_spacing( 24, 16 ),
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => array(
				'relation' => 'and',
				$post_title_dependency,
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'chronicle' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'chronicle' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => chronicle_px2rem( '30px' ),
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				$post_title_dependency,
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'chronicle' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'chronicle' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				$post_title_dependency,
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'chronicle' ),
			'sub_desc'   => esc_html__( 'Select border', 'chronicle' ),
			'dependency' => array(
				'relation' => 'and',
				$post_title_dependency,
			),
		) : null,
		// Post Alignment
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_content_alignment_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Alignment & Hover Settings', 'chronicle' ),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_alignment_' . $unique_id,
			'type'     => 'button_set',
			'title'    => esc_html__( 'Post Alignment', 'chronicle' ),
			'sub_desc' => esc_html__( 'Choose the post alignment', 'chronicle' ),
			'options'  => array(
				'left'   => esc_html__( 'Left', 'chronicle' ),
				'center' => esc_html__( 'Center', 'chronicle' ),
				'right'  => esc_html__( 'Right', 'chronicle' ),
			),
			'std'      => 'center',
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_hover_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Post Hover Effect', 'chronicle' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide hover effect.', 'chronicle' ),
			'std'      => '1',
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'view_more_title_' . $unique_id,
			'type'       => 'text',
			'title'      => esc_html__( 'Read More Title', 'chronicle' ),
			'sub_desc'   => esc_html__( 'Enter the title text to show Read More button.', 'chronicle' ),
			'std'        => 'Read More',
			'dependency' => $post_hover_dependency,
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'view_more_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Read More Typography', 'chronicle' ),
			'std'        => array(
				'preview-text'   => 'Read More Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '700',
				'font-size'      => '15px',
				'color'          => '#1a282f',
				'additional-css' => 'text-align: center;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .view-more',
			),
			'dependency' => $post_hover_dependency,
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'view_more_bg_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Read More Background', 'chronicle' ),
			'std'        => '#ffffff',
			'dependency' => $post_hover_dependency,
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'post_overlay_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Post Overlay Background', 'chronicle' ),
			'args'       => array( 'opacity' => true ),
			'std'        => 'rgba(46,95,214,0.51)',
			'dependency' => $post_hover_dependency,
		) : null,
		// Meta info.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'chronicle' ),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'chronicle' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'chronicle' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'category' => array(
						'label'     => esc_html__( 'Categories', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
				),
				'disabled' => array(
					'author'  => array(
						'label'     => __( 'Author Name', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(
					'category' => array(
						'label'     => esc_html__( 'Categories', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
				),
				'disabled' => array(
					'author'  => array(
						'label'     => __( 'Author Name', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
				),
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'chronicle' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '400',
				'font-size'      => '11px',
				'color'          => '#1a282f',
				'line-height'    => '1.2',
				'letter-spacing' => chronicle_letter_spacing( 11, 182 ),
				'margin-bottom'  => '-5px',
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info',
			),
		) : null,
		// Post Container.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'chronicle' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'chronicle' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'chronicle' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'chronicle' ),
			'sub_desc' => esc_html__( 'Select border', 'chronicle' ),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'chronicle' ),
			'sub_desc' => esc_html__( 'Post margin.', 'chronicle' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => chronicle_px2rem( '40px' ),
				'bottom' => chronicle_px2rem( '40px' ),
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'chronicle' ),
			'sub_desc' => esc_html__( 'Post padding.', 'chronicle' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'chronicle' ),
			'std'   => array(
				'preview-text'  => 'Post Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Public Sans',
				'font-weight'   => '700',
				'font-size'     => '18px',
				'line-height'   => chronicle_line_height( 18, 26 ),
				'margin-bottom' => '5px',
				'color'         => '#1a282f',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_excerpt_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show Post Excerpts', 'chronicle' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide post excerpt.', 'chronicle' ),
			'std'      => '0',
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'post_excerpt_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Post Excerpt Font', 'chronicle' ),
			'std'        => array(
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Public Sans',
				'font-weight'   => '400',
				'font-size'     => '15px',
				'line-height'   => chronicle_line_height( 15, 22 ),
				'color'         => '#1a282f',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
			'dependency' => $post_excerpt_dependency,
		) : null,

		/**
		 * Layout 2 Settings
		 *
		 * @package Chronicle
		 */

		// Section Title.
		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'chronicle' ),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'chronicle' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'chronicle' ),
			'std'      => '1',
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'chronicle' ),
			'std'        => array(
				'preview-text'   => 'Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '700',
				'font-size'      => chronicle_px2rem( '24px' ),
				'line-height'    => '1.2',
				'color'          => '#1a282f',
				'letter-spacing' => chronicle_letter_spacing( 24, 16 ),
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => array(
				'relation' => 'and',
				$post_title_dependency,
			),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'chronicle' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'chronicle' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => chronicle_px2rem( '30px' ),
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				$post_title_dependency,
			),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'chronicle' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'chronicle' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				$post_title_dependency,
			),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'chronicle' ),
			'sub_desc'   => esc_html__( 'Select border', 'chronicle' ),
			'dependency' => array(
				'relation' => 'and',
				$post_title_dependency,
			),
		) : null,
		// Post Alignment
		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_content_alignment_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Alignment & Hover Settings', 'chronicle' ),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_alignment_' . $unique_id,
			'type'     => 'button_set',
			'title'    => esc_html__( 'Post Alignment', 'chronicle' ),
			'sub_desc' => esc_html__( 'Choose the post alignment', 'chronicle' ),
			'options'  => array(
				'left'   => esc_html__( 'Left', 'chronicle' ),
				'center' => esc_html__( 'Center', 'chronicle' ),
				'right'  => esc_html__( 'Right', 'chronicle' ),
			),
			'std'      => 'center',
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_hover_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Post Hover Effect', 'chronicle' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide hover effect.', 'chronicle' ),
			'std'      => '1',
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'view_more_title_' . $unique_id,
			'type'       => 'text',
			'title'      => esc_html__( 'Read More Title', 'chronicle' ),
			'sub_desc'   => esc_html__( 'Enter the title text to show Read More button.', 'chronicle' ),
			'std'        => 'Read More',
			'dependency' => $post_hover_dependency,
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'view_more_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Read More Typography', 'chronicle' ),
			'std'        => array(
				'preview-text'   => 'Read More Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '700',
				'font-size'      => '15px',
				'color'          => '#1a282f',
				'additional-css' => 'text-align: center;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .view-more',
			),
			'dependency' => $post_hover_dependency,
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'view_more_bg_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Read More Background', 'chronicle' ),
			'std'        => '#ffffff',
			'dependency' => $post_hover_dependency,
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'post_overlay_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Post Overlay Background', 'chronicle' ),
			'args'       => array( 'opacity' => true ),
			'std'        => 'rgba(46,95,214,0.51)',
			'dependency' => $post_hover_dependency,
		) : null,
		// Meta info.
		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'chronicle' ),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'chronicle' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'chronicle' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'category' => array(
						'label'     => esc_html__( 'Categories', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
				),
				'disabled' => array(
					'author'  => array(
						'label'     => __( 'Author Name', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(
					'category' => array(
						'label'     => esc_html__( 'Categories', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
				),
				'disabled' => array(
					'author'  => array(
						'label'     => __( 'Author Name', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'chronicle' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'chronicle' ),
							),
						),
					),
				),
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'chronicle' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Public Sans',
				'font-weight'    => '400',
				'font-size'      => '11px',
				'color'          => '#1a282f',
				'line-height'    => '1.2',
				'letter-spacing' => chronicle_letter_spacing( 11, 182 ),
				'margin-bottom'  => '-5px',
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info',
			),
		) : null,
		// Post Container.
		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'chronicle' ),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'chronicle' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'chronicle' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'chronicle' ),
			'sub_desc' => esc_html__( 'Select border', 'chronicle' ),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'chronicle' ),
			'sub_desc' => esc_html__( 'Post margin.', 'chronicle' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => chronicle_px2rem( '40px' ),
				'bottom' => chronicle_px2rem( '40px' ),
			),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'chronicle' ),
			'sub_desc' => esc_html__( 'Post padding.', 'chronicle' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'chronicle' ),
			'std'   => array(
				'preview-text'  => 'Post Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Public Sans',
				'font-weight'   => '700',
				'font-size'     => '28px',
				'line-height'   => '1.2',
				'margin-bottom' => '5px',
				'color'         => '#1a282f',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_excerpt_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show Post Excerpts', 'chronicle' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide post excerpt.', 'chronicle' ),
			'std'      => '0',
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'post_excerpt_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Post Excerpt Font', 'chronicle' ),
			'std'        => array(
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Public Sans',
				'font-weight'   => '400',
				'font-size'     => '15px',
				'line-height'   => chronicle_line_height( 15, 22 ),
				'color'         => '#1a282f',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
			'dependency' => $post_excerpt_dependency,
		) : null,

		/**
		 * Layout HTML Settings
		 *
		 * @package Chronicle
		 */
		( 'layout-html' === $posts_layout ) ? array(
			'id'       => 'post_layout_html_' . $unique_id,
			'type'     => 'ace_editor',
			'mode'     => 'html',
			'title'    => esc_html__( 'HTML Post', 'chronicle' ),
			'sub_desc' => esc_html__( 'Paste your HTML, Text or other code here.', 'chronicle' ),
			'std'      => '<img src="' . get_template_directory_uri() . '/images/banner.jpg">',
		) : null,
		( 'layout-html' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'chronicle' ),
			'sub_desc' => esc_html__( 'Post margin.', 'chronicle' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => chronicle_px2rem( '108px' ),
			),
		) : null,
		( 'layout-html' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'chronicle' ),
			'sub_desc' => esc_html__( 'Post padding.', 'chronicle' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

	);
endforeach;
