<?php
/**
 * Single Tab
 *
 * @package Chronicle
 */

$menus['single-general'] = array(
	'title' => esc_html__( 'General', 'chronicle' ),
	'desc'  => esc_html__( 'From here, you can control the appearance and functionality of your single posts page.', 'chronicle' ),
);

// Dependency check - Featured Image Size
$featured_image_size = array(
	'relation' => 'and',
	array(
		'field'      => 'featured_image_size',
		'value'      => 'full',
		'comparison' => '==',
	),
);

$sections['single-general'] = array(

	array(
		'id'       => 'show_single_featured',
		'type'     => 'switch',
		'title'    => esc_html__( 'Show Featured image', 'chronicle' ),
		'sub_desc' => esc_html__( 'Enable/Disable the Featured images in the single post.', 'chronicle' ),
		'std'      => '1',
	),
	array(
		'id'       => 'featured_image_size',
		'type'     => 'button_set',
		'title'    => esc_html__( 'Header Size', 'chronicle' ),
		'sub_desc' => esc_html__( 'Choose the featured image size', 'chronicle' ),
		'options'  => array(
			'default' => esc_html__( 'Content Size', 'chronicle' ),
			'full'    => esc_html__( 'Full Width', 'chronicle' ),
		),
		'std'      => 'full',
	),
	array(
		'id'         => 'featured_image_margin',
		'type'       => 'margin',
		'title'      => esc_html__( 'Header Image Margin', 'chronicle' ),
		'sub_desc'   => esc_html__( 'Set header image margin from here.', 'chronicle' ),
		'std'        => array(
			'top'    => chronicle_px2rem( '40px' ),
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		),
		'dependency' => $featured_image_size,
	),
	array(
		'id'         => 'featured_image_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Header Image Padding', 'chronicle' ),
		'sub_desc'   => esc_html__( 'Set header image padding from here.', 'chronicle' ),
		'std'        => array(
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		),
		'dependency' => $featured_image_size,
	),
	array(
		'id'         => 'featured_text_alignment',
		'type'       => 'button_set',
		'title'      => esc_html__( 'Alignment', 'chronicle' ),
		'sub_desc'   => esc_html__( 'Choose the featured image text alignment', 'chronicle' ),
		'options'    => array(
			'left'   => esc_html__( 'Left', 'chronicle' ),
			'center' => esc_html__( 'Center', 'chronicle' ),
			'right'  => esc_html__( 'Right', 'chronicle' ),
		),
		'std'        => 'center',
		'dependency' => $featured_image_size,
	),

	array(
		'id'         => 'show_prev_next',
		'type'       => 'switch',
		'title'      => esc_html__( 'Show preview and next article buttons', 'chronicle' ),
		'sub_desc'   => esc_html__( 'Use this button to show or hide preview and next article buttons.', 'chronicle' ),
		'std'        => '0',
		'dependency' => $featured_image_size,
	),

	array(
		'id'       => 'mts_single_post_layout',
		'type'     => 'layout2',
		'title'    => esc_html__( 'Single Post Layout', 'chronicle' ),
		'sub_desc' => esc_html__( 'Customize the look of single posts', 'chronicle' ),
		'options'  => array(
			'enabled'  => array(
				'content' => array(
					'label'     => esc_html__( 'Post Content', 'chronicle' ),
					'subfields' => array(),
				),
				'tags'    => array(
					'label'     => esc_html__( 'Tags', 'chronicle' ),
					'subfields' => array(),
				),
				'author'  => array(
					'label'     => esc_html__( 'Author Box', 'chronicle' ),
					'subfields' => array(),
				),
				'related' => array(
					'label'     => esc_html__( 'Related Posts', 'chronicle' ),
					'subfields' => array(
						array(
							'id'       => 'mts_related_posts_taxonomy',
							'type'     => 'switch',
							'title'    => esc_html__( 'Related Posts Taxonomy', 'chronicle' ),
							'options'  => array(
								'tags'       => esc_html__( 'Tags', 'chronicle' ),
								'categories' => esc_html__( 'Categories', 'chronicle' ),
							),
							'class'    => 'green',
							'sub_desc' => esc_html__( 'Related Posts based on tags or categories.', 'chronicle' ),
							'std'      => 'categories',
						),
					),
				),
			),
			'disabled' => array(
				'subscribe' => array(
					'label'     => esc_html__( 'Subscribe Box', 'chronicle' ),
					'subfields' => array(),
				),
			),
		),
	),

	array(
		'id'       => 'mts_single_headline_meta_info',
		'type'     => 'layout2',
		'title'    => esc_html__( 'Single Meta Info', 'chronicle' ),
		'sub_desc' => esc_html__( 'Organize how you want the post meta info to appear on single page', 'chronicle' ),
		'options'  => array(
			'enabled'  => array(
				'category' => array(
					'label'     => esc_html__( 'Categories', 'chronicle' ),
					'subfields' => array(
						array(
							'id'    => 'mts_single_meta_info_category_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'chronicle' ),
						),
					),
				),
				'date'     => array(
					'label'     => esc_html__( 'Date', 'chronicle' ),
					'subfields' => array(
						array(
							'id'    => 'mts_single_meta_info_date_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'chronicle' ),
						),
					),
				),
			),
			'disabled' => array(
				'author'  => array(
					'label'     => esc_html__( 'Author Name', 'chronicle' ),
					'subfields' => array(
						array(
							'id'    => 'mts_single_meta_info_author_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'chronicle' ),
						),
					),
				),
				'comment' => array(
					'label'     => esc_html__( 'Comment Count', 'chronicle' ),
					'subfields' => array(
						array(
							'id'    => 'mts_single_meta_info_comment_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'chronicle' ),
						),
					),
				),
			),
		),
	),

	array(
		'id'       => 'mts_author_comment',
		'type'     => 'switch',
		'title'    => esc_html__( 'Highlight Author Comment', 'chronicle' ),
		'sub_desc' => esc_html__( 'Use this button to highlight author comments.', 'chronicle' ),
		'std'      => '1',
	),

);
